pub struct TransactionPrimitive<B>where
B: Backend,{
pub read_floats: Vec<<B as BackendTypes>::FloatTensorPrimitive>,
pub read_qfloats: Vec<<B as BackendTypes>::QuantizedTensorPrimitive>,
pub read_ints: Vec<<B as BackendTypes>::IntTensorPrimitive>,
pub read_bools: Vec<<B as BackendTypes>::BoolTensorPrimitive>,
/* private fields */
}Expand description
Contains all tensor primitives that are going to be read.
Fields
read_floats: Vec<<B as BackendTypes>::FloatTensorPrimitive>Float tensors.
read_qfloats: Vec<<B as BackendTypes>::QuantizedTensorPrimitive>Quantized tensors.
read_ints: Vec<<B as BackendTypes>::IntTensorPrimitive>Int tensors.
read_bools: Vec<<B as BackendTypes>::BoolTensorPrimitive>Bool tensors.
Implementations
Sourceimpl<B> TransactionPrimitive<B>where
B: Backend,
impl<B> TransactionPrimitive<B>where
B: Backend,
Sourcepub fn new(
read_floats: Vec<<B as BackendTypes>::FloatTensorPrimitive>,
read_qfloats: Vec<<B as BackendTypes>::QuantizedTensorPrimitive>,
read_ints: Vec<<B as BackendTypes>::IntTensorPrimitive>,
read_bools: Vec<<B as BackendTypes>::BoolTensorPrimitive>,
) -> TransactionPrimitive<B>
pub fn new( read_floats: Vec<<B as BackendTypes>::FloatTensorPrimitive>, read_qfloats: Vec<<B as BackendTypes>::QuantizedTensorPrimitive>, read_ints: Vec<<B as BackendTypes>::IntTensorPrimitive>, read_bools: Vec<<B as BackendTypes>::BoolTensorPrimitive>, ) -> TransactionPrimitive<B>
Creates a new transaction.
Sourcepub async fn execute_async(self) -> Result<Vec<TensorData>, ExecutionError>
pub async fn execute_async(self) -> Result<Vec<TensorData>, ExecutionError>
Executes the transaction asynchronously and returns the data in the same order in which they were registered.