Ruda model configuration, modules, parameters, records and data loading.
Re-exports
pub use serde;
Modules
- config
- The configuration module.
- data
std - Data module.
- module
- Module for the neural network module.
- prelude
- Structs and macros used by most projects. Add
use ruda::prelude::*to your code to quickly get started with Ruda. - record
- Module for the recorder.
- tensor
- Module for the tensor.
Macros
- empty
- Constant macro.
Structs
- Tensor
- A tensor with a given backend, shape and data type.